==> haskell-optparse-simple-0.1.1.4-496-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optparse-simple
version:              0.1.1.4
visibility:           public
id:                   optparse-simple-0.1.1.4-7ONiq51klrC2gnC2wDqlJ
key:                  optparse-simple-0.1.1.4-7ONiq51klrC2gnC2wDqlJ
license:              BSD-3-Clause
copyright:            2015-2017 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               FP Complete
homepage:             https://github.com/fpco/optparse-simple#readme
synopsis:             Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>

category:             Options
abi:                  58d088e110562077972277923cb1b49c
exposed:              True
exposed-modules:      Options.Applicative.Simple
hidden-modules:       Paths_optparse_simple
import-dirs:          /usr/lib/ghc-9.4.8/site-local/optparse-simple-0.1.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/optparse-simple-0.1.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/optparse-simple-0.1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optparse-simple
hs-libraries:         HSoptparse-simple-0.1.1.4-7ONiq51klrC2gnC2wDqlJ
depends:
    base-4.17.2.1 githash-0.1.6.3-HDOJGPp6sZ83FTq7EHV1x4
    optparse-applicative-0.18.1.0-3qYZezrQAxc4lJKAil0WN1
    template-haskell-2.19.0.0 th-compat-0.1.6-9PXj0O23exa9gYDyUWzgwd
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock

haddock-html:         /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-simple-0.1.1.4-521-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optparse-simple
version:              0.1.1.4
visibility:           public
id:                   optparse-simple-0.1.1.4-sMKm2XicSO3N9l90qgjBN
key:                  optparse-simple-0.1.1.4-sMKm2XicSO3N9l90qgjBN
license:              BSD-3-Clause
copyright:            2015-2017 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               FP Complete
homepage:             https://github.com/fpco/optparse-simple#readme
synopsis:             Simple interface to optparse-applicative
description:
    Please see the README at <https://www.stackage.org/package/optparse-simple>

category:             Options
abi:                  b0574cbc3f0f468242f2de7b41495352
exposed:              True
exposed-modules:      Options.Applicative.Simple
hidden-modules:       Paths_optparse_simple
import-dirs:          /usr/lib/ghc-9.4.8/site-local/optparse-simple-0.1.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/optparse-simple-0.1.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/optparse-simple-0.1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optparse-simple
hs-libraries:         HSoptparse-simple-0.1.1.4-sMKm2XicSO3N9l90qgjBN
depends:
    base-4.17.2.1 githash-0.1.6.3-9GBeKMqGAcC72CXb0q8NgF
    optparse-applicative-0.18.1.0-t4C6chS8YH5x9x9VuRkT0
    template-haskell-2.19.0.0 th-compat-0.1.6-4cyAmuzH3Hz7AWJSIlHP5n
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock

haddock-html:         /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
